@@ -25,7 +25,3 @@ ggplot2::aes
 #' @importFrom ggplot2 ggsave
 #' @export
 ggplot2::ggsave
-
-#' @importFrom gridExtra grid.arrange
-#' @export
-gridExtra::grid.arrange
