@@ -16,17 +16,17 @@ test_that("tie_is_loop works", {
 })
 
 test_that("tie_is_bridge works", {
-  expect_equal(length(tie_is_bridge(graph1)), graph_ties(graph1))
+  expect_equal(length(tie_is_bridge(graph1)), network_ties(graph1))
 })
 
 test_that("tie_is_max works", {
-  expect_equal(length(tie_is_max(tie_betweenness(ison_brandes))), graph_ties(ison_brandes))
+  expect_equal(length(tie_is_max(tie_betweenness(ison_brandes))), network_ties(ison_brandes))
   expect_equal(sum(tie_is_max(tie_betweenness(ison_brandes)) == TRUE), 1)
   expect_s3_class(tie_is_max(tie_betweenness(ison_brandes)), "logical")
 })
 
 test_that("tie_is_min works", {
-  expect_equal(length(tie_is_min(tie_betweenness(ison_brandes))), graph_ties(ison_brandes))
+  expect_equal(length(tie_is_min(tie_betweenness(ison_brandes))), network_ties(ison_brandes))
   expect_equal(sum(tie_is_min(tie_betweenness(ison_brandes)) == TRUE), 1)
   expect_s3_class(tie_is_min(tie_betweenness(ison_brandes)), "logical")
 })
